@@ -9,11 +9,13 @@
 
 #include "calendarsupport_export.h"
 
-#include <ItemMonitor>
+#include <Akonadi/ItemMonitor>
 
 #include <QDate>
 #include <QWidget>
 
+#include <memory>
+
 class QAbstractItemModel;
 
 namespace Akonadi
@@ -23,6 +25,8 @@ class ETMCalendar;
 
 namespace CalendarSupport
 {
+class IncidenceViewerPrivate;
+
 /**
  * @short A viewer component for incidences in Akonadi.
  *
@@ -138,11 +142,9 @@ private:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<IncidenceViewerPrivate> const d;
 
     Q_PRIVATE_SLOT(d, void slotParentCollectionFetched(KJob *))
     //@endcond
 };
 }
-
